/* Smart Layers Library v2 by Al Mackey, 4/12/2002
 * Feel free to use this library and distribute it unmodified.
 * Flash is for wussies!
 *
 * ABOUT:
 * This is a JavaScript library of routines that can set up and
 * manage layers in just about any HTML document.  By "layers", I
 * mean floating bits of dynamic content that can be simple images
 * or chunks of rendered HTML.  SmartLayers work with MicroSoft
 * Internet Explorer 5+, NetScape Navigator 4.7x, and any browser
 * using the Gecko engine (NetScape 6+, Mozilla, etc).  It has been
 * successfully tested on Windows, Macintosh and UNIX.
 *
 * USAGE:
 * Smart Layers are JavaScript objects that provide a much-needed
 * level of abstraction between your code and the various methods
 * browsers use to create and control dynamic elements.  These
 * objects provide simple routines that handle the strange methods
 * used by noncompliant browsers to do common actions to your
 * layers.
 *
 * To use SmartLayers, first include its routines in an HTML
 * document with a script tag, like this:
 *
 *   <script language="JavaScript" src="smartlayers.js"></script>
 *
 * After that, in your own script tag or JS file, you can access
 * the SmartLayers routines.  A SmartLayer is set up with a JS
 * command like this (the variable name MyLayer is used just as
 * an example):
 *
 * var MyLayer = new SmartLayer(width, source, IsImage, x, y, z, page);
 *   width is the width of the layer in pixels (needed for Netscape-isms).
 *   source is an HTML string or an image URL.
 *   IsImage should be true if source is an image URL, otherwise false.
 *   x and y are the screen coordinates of the layer's top left corner.
 *   z is the z-index of the layer (higher Z indexes will be on top).
 *   page is the DOM in which to make the layer.
 *   You may omit page if you want the layer to be a part of the document
 *   that the calling code is attached to.
 *
 * The Smart Layer can then be moved and otherwise modified with its
 * attached routines:
 *
 * MyLayer.MoveTo(x,y);
 *   x and y are the screen coordinates of the layer's top left corner.
 *
 * MyLayer.SetDepth(z);
 *   Sets the layer's z-index.
 *
 * MyLayer.SetSource(source);
 *   source is an HTML string or an image URL, depending on weather the
 *   layer was set up with IsImage to false or true, respectively.
 *   Re-setting source of HTML layers may cause a brief flicker in some
 *   browsers.  Re-setting an image source may cause flickering or delay
 *   only if the image is not preloaded.
 *
 * MyLayer.Visible(visibility);
 *   visibility should be boolean, and controls if the layer is displayed
 *
 * Various variables are available for read-only use to check the layer's
 * current state:
 *   MyLayer.x - X coordinate of left edge
 *   MyLayer.y - Y coordinate of top edge
 *   MyLayer.z - Z index
 *   MyLayer.vis - Boolean value of layer's visibility
 *   MyLayer.IsImage - State of the IsImage flag when layer was created
 *
 */

var Agent=navigator.userAgent.toLowerCase();
var IdCount = 0;

var IsIE = ((Agent.indexOf('msie') != -1) && (Agent.indexOf('opera') == -1));
var IsGecko = (Agent.indexOf('gecko') != -1);
var IsOpera = (Agent.indexOf('opera') != -1);

function SmartLayer(width, source, IsImage, x, y, z, page) {
  var doc = document;
  if (page != null) {doc = page.document;}
  IdCount++;
  var alphaid = CreateAlphaID(IdCount);
  var id = "smartlayer"+alphaid;
  var imgid = "slimage"+alphaid;
  this.IsImage = IsImage;
  this.x = x;
  this.y = y;
  this.z = z;
  this.vis = true;
  if (IsIE) {
    var c = '\n<div id='+id+' style="position:absolute; visibility:show; left:'+x+'; top:'+y+'; width:'+width+'; z-index:'+z+';">';
    if (IsImage) {c += '<img src="'+source+'" id="'+imgid+'">';}
    else {c += source;}
    c += '</div>';
    doc.body.insertAdjacentHTML("BeforeEnd",c);
    this.layerref = doc.all[id];
    if (IsImage) {this.imgref = doc.all[imgid];}
  } else if (IsGecko) {
    this.layerref = doc.createElement("div");
    this.layerref.id = id;
    this.layerref.style.position = "absolute";
    this.layerref.style.left = x + "px";
    this.layerref.style.top = y + "px";
    this.layerref.style.width = width + "px";
    this.layerref.style.zIndex = z;
    doc.body.appendChild(this.layerref);
    var c = source;
    if (IsImage) {c = '<img src="'+source+'" id="'+imgid+'">';}
    this.layerref.innerHTML = c;
    if (IsImage) {this.imgref = doc.getElementById(imgid);}
  } else if (IsOpera) {
    alert("Opera not supported yet.");
    return;
  } else {
    if (page) {
      this.layerobj = new Layer(width, page);
    } else {
      this.layerobj = new Layer(width);
    }
    this.layerobj.x = x;
    this.layerobj.y = y;
    this.layerobj.zIndex = z;
    var c = source;
    if (IsImage) {c = '<img src="'+source+'" id="'+imgid+'">';}
    this.layerobj.document.open();
    this.layerobj.document.write(c);
    this.layerobj.document.close();
    this.layerobj.hidden = false;
  }
}

function CreateAlphaID(num) {
  num = parseInt(num);
  var str = "";
  while ((num > 0)||(str=="")) {
    str = String.fromCharCode((num%26)+97)+str;
    num = parseInt(num/26);
  }
  return str;
}

SmartLayer.prototype.MoveTo = function(x,y) {
  if ((IsIE)||(IsGecko)) {
    if (x != null) {this.layerref.style.left = x + "px"; this.x = x;}
    if (y != null) {this.layerref.style.top = y + "px"; this.y = y;}
  } else if (IsOpera) {
    if (x != null) {this.layerref.style.pixelLeft = x + "px"; this.x = x;}
    if (y != null) {this.layerref.style.pixelTop = y + "px"; this.y = y;}
  } else {
    if (x != null) {this.layerobj.x = x; this.x = x;}
    if (y != null) {this.layerobj.y = y; this.y = y;}
  }
}

SmartLayer.prototype.SetDepth = function(z) {
  if ((IsIE)||(IsGecko)||(IsOpera)) {
    this.layerref.style.zIndex = z;
  } else {
    this.layerobj.zIndex = z;
  }
  this.z = z;
}

SmartLayer.prototype.SetSource = function(source) {
  if (this.IsImage) {
    if ((IsIE)||(IsGecko)) {
      this.imgref.src = source;
    } else {
      this.layerobj.document.images[0].src = source;
    }
  } else {
    if ((IsIE)||(IsGecko)) {
      this.layerref.innerHTML = source;
    } else {
      this.layerobj.document.open();
      this.layerobj.document.write(source);
      this.layerobj.document.close();
    }
  }
}

SmartLayer.prototype.Visible = function(vis) {
  vis = (vis)?true:false;
  this.vis = vis;
  if ((IsIE)||(IsGecko)||(IsOpera)) {
    this.layerref.style.visibility = (vis)?'visible':'hidden';
  } else {
    this.layerobj.hidden = (!vis);
  }
}
